@@ -1,4 +1,4 @@
-knit_print.data.frame = function(x, ...) {
+knit_print.data.frame <- function(x, ...) {
   context <- render_context()
   if (!is.null(context$df_print)) {
     if (identical(context$df_print, knitr::kable)) {
@@ -13,4 +13,13 @@ knit_print.data.frame = function(x, ...) {
   }
 }
 
+#' @export
+#' @importFrom knitr knit_print
+knit_print.tbl_sql <- knit_print.data.frame
+
+#' @export
+knit_print.grouped_df <- knit_print.data.frame
+
+#' @export
+knit_print.rowwise_df <- knit_print.data.frame
 
